@@ -1,9 +1,6 @@
 from typing import Any, Dict, Optional, Union
 
-try:
-    from typing import TypedDict
-except Exception:
-    from mypy_extensions import TypedDict
+from typing_extensions import Literal, TypedDict
 
 
 class ProxiedBucketNames(TypedDict):
@@ -13,19 +10,24 @@ class ProxiedBucketNames(TypedDict):
 
 
 class DjangoCacheAccountInfoConfig(TypedDict):
-    type: str  # only "django-cache" is valid
+    type: Literal["django-cache"]
     cache: str
 
 
 class InMemoryAccountInfoConfig(TypedDict):
-    type: str  # only "memory" is valid
+    type: Literal["memory"]
 
 
 class SqliteAccountInfoConfig(TypedDict):
-    type: str  # only "sqlite" is valid
+    type: Literal["sqlite"]
     databasePath: str
 
 
+class CDNConfig(TypedDict):
+    baseUrl: str
+    includeBucketUrlSegments: bool
+
+
 class BackblazeB2StorageOptions(TypedDict):
     """Configuration options."""
 
@@ -36,12 +38,13 @@ class BackblazeB2StorageOptions(TypedDict):
     authorizeOnInit: bool
     validateOnInit: bool
     allowFileOverwrites: bool
+    accountInfo: Optional[Union[DjangoCacheAccountInfoConfig, InMemoryAccountInfoConfig, SqliteAccountInfoConfig]]
+    forbidFilePropertyCaching: bool
+    specificBucketNames: ProxiedBucketNames
+    cdnConfig: Optional[CDNConfig]
     # see: https://b2-sdk-python.readthedocs.io/en/master/api/api.html#b2sdk.v1.B2Api.create_bucket
     nonExistentBucketDetails: Optional[Dict[str, Union[str, Dict[str, Any]]]]
     defaultFileInfo: Dict[str, Any]
-    specificBucketNames: ProxiedBucketNames
-    accountInfo: Optional[Union[DjangoCacheAccountInfoConfig, InMemoryAccountInfoConfig, SqliteAccountInfoConfig]]
-    forbidFilePropertyCaching: bool
 
 
 def getDefaultB2StorageOptions() -> BackblazeB2StorageOptions:
@@ -53,9 +56,10 @@ def getDefaultB2StorageOptions() -> BackblazeB2StorageOptions:
         "authorizeOnInit": True,
         "validateOnInit": True,
         "allowFileOverwrites": False,
-        "nonExistentBucketDetails": None,
-        "defaultFileInfo": {},
-        "specificBucketNames": {"public": None, "loggedIn": None, "staff": None},
         "accountInfo": {"type": "django-cache", "cache": "django-backblaze-b2"},
         "forbidFilePropertyCaching": False,
+        "specificBucketNames": {"public": None, "loggedIn": None, "staff": None},
+        "cdnConfig": None,
+        "nonExistentBucketDetails": None,
+        "defaultFileInfo": {},
     }
